<!-- Auto generated. Run 'inv release' in order to update -->

# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2025-01-05

#### 🚀 Features
- Add photos support ([#3]) - [dc2caed]

#### 📘 Documentation
- Add documentation page ([#6]) - [a630a92]

#### 💻 Tooling
- Replace `make` with [`invoke`](https://www.pyinvoke.org/) (see `inv help`) ([#5]) - [1c26026]
- Change from `poetry` to [`uv`](https://docs.astral.sh/uv/) ([#4]) - [748bca2]


[#3]: https://github.com/wodore/hut-services/pull/3
[dc2caed]: https://github.com/wodore/hut-services/commit/dc2caed474dec35516c2b551dd47f5c187513603

[#6]: https://github.com/wodore/hut-services/pull/6
[a630a92]: https://github.com/wodore/hut-services/commit/a630a92420d80e0bcfd42d998de9b9dfa1f374d9

[#5]: https://github.com/wodore/hut-services/pull/5
[1c26026]: https://github.com/wodore/hut-services/commit/1c2602652e3e279d4c62f62179c19d9ff3b00c07
[#4]: https://github.com/wodore/hut-services/pull/4
[748bca2]: https://github.com/wodore/hut-services/commit/748bca223545c160fb0f817cd78966c63883a17c

[0.1.0]: https://github.com/wodore/hut-services/releases/tag/v0.1.0
